summaryrefslogtreecommitdiff
path: root/src/theory/arith/arithvar.h
diff options
context:
space:
mode:
authorTim King <taking@cs.nyu.edu>2012-04-27 14:47:10 +0000
committerTim King <taking@cs.nyu.edu>2012-04-27 14:47:10 +0000
commitf813ed144b0945334e03bfd769ea3c2cf8b75843 (patch)
treee70c9bddf5445aac50b5080c2b1719e6ffb478e0 /src/theory/arith/arithvar.h
parent68237f7d39a03905be4cc133a42083fc3342adb4 (diff)
This merges in the branch cvc4/branches/arithmetic/matrix into trunk.
- Splits the functionality of having a sparse matrix of Ts and a solved matrix of rationals in tableau. - Splits ArithVarSet into DenseMap and CDDenseSet and simplifies the code. - No performance loss!
Diffstat (limited to 'src/theory/arith/arithvar.h')
-rw-r--r--src/theory/arith/arithvar.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/theory/arith/arithvar.h b/src/theory/arith/arithvar.h
index 432f9f0c2..924e91bf5 100644
--- a/src/theory/arith/arithvar.h
+++ b/src/theory/arith/arithvar.h
@@ -14,7 +14,7 @@
** \brief Defines ArithVar which is the internal representation of variables in arithmetic
**
** This defines ArithVar which is the internal representation of variables in
** arithmetic. This is a typedef from uint32_t to ArithVar.
** This file also provides utilities for ArithVars.
**/
@@ -25,16 +25,18 @@
#define __CVC4__THEORY__ARITH__ARITHVAR_H
#include <limits>
-#include <stdint.h>
#include <ext/hash_map>
#include "expr/node.h"
#include "context/cdhashset.h"
+#include "context/cdhashset.h"
+
+#include "util/index.h"
namespace CVC4 {
namespace theory {
namespace arith {
-typedef uint32_t ArithVar;
+typedef Index ArithVar;
const ArithVar ARITHVAR_SENTINEL = std::numeric_limits<ArithVar>::max();
//Maps from Nodes -> ArithVars, and vice versa
generated by cgit on debian on lair
@@ -14,7 +14,7 @@
**
** This defines ArithVar which is the internal representation of variables in
- ** arithmetic. This is a typedef from uint32_t to ArithVar.
+ ** arithmetic. This is a typedef from Index to ArithVar.
** This file also provides utilities for ArithVars.
**/
contact matthew@masot.net with questions or feedback